<div align="center">
  <h1>
    <br/>
    <img src="../../../img/techtype_rocket_logo.jpg" alt="techtype_rocket_logo" width="60"/>
    <br/>
    TechType Rocket
  </h1>
</div>

- [Description](#description)
- [Run TechType Rocket User Interface](#techtype-rocket-ui)
- [Known Limitations](#known-limitations)
- [Related Materials](#related-material)
- [About RQle.AI](#about-rqle-ai)
- [Disclaimer](#disclaimer)

## Description <a name="description"></a>
Struggling to break into the tech blogging world? TechType Rocket is your one-stop platform designed to equip aspiring writers with the skills and guidance to confidently create engaging tech blogs for diverse audiences.

With TechType Rocket, you'll be ready to:
* Publish **high-quality tech blogs** that resonate with your target audience.
* Establish yourself as a **credible voice** in the tech community.
* Build a loyal following eager to consume your **insightful content**.

To limit the generation of toxic or nonsensical content, we leverage the `llm-guard` library with the following guardrails:
* Input Validation:
  * Topics do not include prompt injection
  * Topics are expressed in English
  * Topics do not include toxic language
* Output Validation:
  * Generated text is not nonsensical / gibberish
  * Generated text is relevant to the topics provided by users
  * Generated text does not include negative sentiment content
  * Generated text does not include toxic language

## Run TechType Rocket User Interface <a name="techtype-rocket-ui"></a>
To start the User Interface (UI) for TechType Rocket, the following command should be executed
```
 streamlit run .\rqle_ai_langchain_util\apps\techtype_rocket\techtype_rocket_ui.py
```

## Known Limitations <a name="known-limitations"></a>
* Word count limit is not respected by the LLM
  * For Google Gemini, this is a wll-documented limitations (see [reddit](https://www.reddit.com/r/Bard/comments/1ao3oyi/gemini_is_absolutely_horrible_when_you_tell_it_to/))
* Identified an issue with the integration of Meta LlAMA2 when hosted on AWS Bedrock
* Downgraded the version of `llm-guard` due to conflicting versions with `langchain` libraries 

## Related Materials <a name="related-material"></a>

## About RQle.AI <a name="about-rqle-ai"></a>
[**RQle.AI**](https://www.linkedin.com/company/102641077) believes in the transformative potential of Generative AI. More specifically, it focuses on 
showcasing real-world applications of how Generative AI can empower individuals and organizations worldwide in addressing 
customers' "*job to be done*" problems and create value for them.

## Disclaimer <a name="disclaimer"></a>
This application was partially generated by a large language model (Generative AI). While the AI assisted in the 
generation of ideas and content, the final solution and its implementation remain the responsibility of the human user. 
It is important to critically evaluate and revise the AI-generated content to ensure its accuracy, appropriateness, 
and ethical implications.

<div style="text-align: center;">
  <hr/>
  <img src="../../../img/rqle_ai_logo_alt.jpeg" alt="RQle.AI" width="60"/>
  &nbsp; RQle.AI - 2024
</div>